netapp_ontap.models.lun_map_reporting_nodes API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.lun_map_reporting_nodes`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class LunMapReportingNodesSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the LunMapReportingNodes object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `links: LunMapReportingNodesLinks GET`

    The links field of the lun_map_reporting_nodes.

  `name: str GET POST`

    The name of the node.
    Either `uuid` or `name` are required in POST.

    Example: node1

  `uuid: str GET POST`

    The unique identifier of the node.
    Either `uuid` or `name` are required in POST.

    Example: 5ac8eb9c-4e32-dbaa-57ca-fb905976f54e